#import <React/RCTBridgeModule.h>

@interface RCTGoogleAnalyticsBridge : NSObject <RCTBridgeModule>
@end
